@@ -63,8 +63,13 @@ CONFIG_DIR = os.path.join(os.path.expanduser('~'), ".elisa-0.5")
 # - custom user configuration is lost between releases
 # - prevents configuration upgrade bugs
 # - avoid configuration upgrade work
-version_string = "_".join([str(n) for n in version_info])
-CONFIG_FILE = "elisa_%s.conf" % version_string
+#version_string = "_".join([str(n) for n in version_info])
+#CONFIG_FILE = "elisa_%s.conf" % version_string
+
+# FIXME: hardcoded configuration file name in order to avoid its rewriting
+# starting from Elisa 0.5.6; this is a temporary solution that is valid for
+# the moment given that there is no configuration to upgrade for now.
+CONFIG_FILE = "elisa_0_5_6.conf"
 
 TRANS_FILE = "data/translations.lst"
 PICTURES_CACHE = os.path.join(CONFIG_DIR, 'pictures_cache')
@@ -75,7 +80,7 @@ version = '%(version)s'
 install_date = '%(install_date)s'
 resource_providers = ['amazon.resource_provider:AmazonResourceProvider', 'discogs.discogs_resource:DiscogsResource', 'database.media_scanner:MediaScanner', 'weather.report_provider:WeatherReportProvider', 'base.local_resource:LocalResource', 'youtube.resource_provider:YoutubeResourceProvider', 'shoutcast.shoutcast_resource:ShoutcastResource', 'flickr.resource_provider:FlickrResourceProvider', 'wmd.wmd_resource:WMDResource', 'filtered_shares.filtered_shares_resource:FilteredSharesResource', 'coherence.coherence_resource:CoherenceResource', 'coherence.upnp_resource:UpnpResource', 'smbwin32.smbwin32_resource:SmbWin32Resource', 'elisa_updater.resource_provider:UpdaterResourceProvider', 'ipod.ipod_resource:IpodResource', 'hal.hal_resource:HALResource', 'avahi.avahi_resource_provider:AvahiResourceProvider', 'daap.daap_resource_provider:DaapResourceProvider']
 metadata_providers = []
-service_providers = ['coherence.coherence_service:CoherenceService', 'osso.osso_service:OssoService', 'gnome.gnome_screensaver_service:GnomeScreensaverService']
+service_providers = ['coherence.coherence_service:CoherenceService', 'osso.osso_service:OssoService', 'gnome.gnome_screensaver_service:GnomeScreensaverService','database.dbus_service:DatabaseDBusServiceProvider']
 input_providers = ['winremote.streamzap_input:StreamzapInput', 'lirc.lirc_input:LircInput']
 frontends = ['frontend1']
 # database connection string. see https://storm.canonical.com/Manual
