@@ -52,6 +52,7 @@ class ConfigUpgrader(log.Loggable):
                            '0.3.4.rc1', '0.3.4.rc2',),
                           self._update_0_3_3_to_0_3_4),
                          (('0.3.4','0.3.4.1'), self._update_0_3_4_to_0_3_5),
+                         (('0.5.7', '0.5.8'), self._update_0_5_7_to_0_5_8),
                           ]
         
     def _get_version_index_upgrade(self, version_str):
@@ -131,6 +132,22 @@ class ConfigUpgrader(log.Loggable):
         self.debug("Doing a backup to the old config on %s", full_path)
         cfg.write(full_path)
 
+    def _update_0_5_7_to_0_5_8(self, cfg=None):
+        self.info('Upgrading from 0.5.7 to 0.5.8')
+        self._backup((0, 5, 7), cfg)
+        if not cfg:
+            cfg = self._current_config
+
+        service_providers = cfg.get_option('service_providers',
+                                           section='general', default=[])
+        new_service = 'database.dbus_service:DatabaseDBusServiceProvider'
+        if new_service not in service_providers:
+            service_providers = self._extend_list(service_providers, 
+                                                  [new_service])
+
+        self._current_version = '0.5.8'
+        return cfg
+
     def _update_0_3_4_to_0_3_5(self, cfg=None):
         self.info('Upgrading from 0.3.4 to 0.3.5')
         self._backup((0, 3, 4), cfg)
