@@ -43,14 +43,15 @@ from elisa.core.plugin_registry import PluginRegistry
 from elisa.core.config import Config
 from elisa.extern.epr.egg_parser import EggParser
 from elisa.core.log import Loggable
+from elisa.core import common
 
 from elisa.core.epm.egg_plugin import EggPlugin
 from elisa.core.epm.egg_repository import create_repository_from_source
 from elisa.core.epm.exceptions import *
 
 # HACK
-ELISA_PLUGINS_DIR = os.path.join(os.path.expanduser('~'), '.elisa', 'plugins')
-ELISA_CORE_DIR = os.path.join(os.path.expanduser('~'), '.elisa', 'core')
+ELISA_PLUGINS_DIR = os.path.join(CONFIG_DIR, 'plugins')
+ELISA_CORE_DIR = os.path.join(CONFIG_DIR, 'core')
 
 # FIXME: load from config
 DEFAULT_REPOSITORIES = ["http://elisa-plugins.fluendo.com/main/xmlrpc"]
@@ -107,9 +108,14 @@ class EggRegistry(Loggable):
         self.dynamic_repositories = []
         self._discover_dynamic_repositories()
 
-        config_file = os.path.join(CONFIG_DIR, CONFIG_FILE)
-        self.plugin_registry = PluginRegistry(Config(config_file))
-        self.plugin_registry.load_plugins(self.plugin_dirs)
+        # reuse common.application if the egg_registry directly inside
+        # a running Elisa
+        if common.application:
+            self.plugin_registry = common.application.plugin_registry
+        else:
+            config_file = os.path.join(CONFIG_DIR, CONFIG_FILE)
+            self.plugin_registry = PluginRegistry(Config(config_file))
+            self.plugin_registry.load_plugins(self.plugin_dirs)
 
     def _load_static_repositories(self):
         # FIXME: get static repositories' sources from config file.
