@@ -22,8 +22,6 @@ Component instances management
 __maintainer__ = 'Philippe Normand <philippe@fluendo.com>'
 
 from elisa.core import log
-from elisa.core.component import ComponentError, InitializeFailure, UnMetDependency
-from elisa.core.plugin_registry import ComponentNotFound
 from elisa.core.utils import classinit
 from elisa.core import common
 from twisted.internet import defer, task
@@ -62,64 +60,45 @@ class Manager(log.Loggable):
 
         self._components = []
 
-    def initialize(self):
+    def load_components(self, components_names):
         """
-        This function is called when the application has initialized completely
-        """
-        return self._load_providers()
+        Load a list of components in sequence.
 
-    def _load_providers(self):
-        """ Ask the plugin registry to create all the providers
-        components defined in section 'general' of the config
+        @param  components_names:    list of strings with the names of
+                                     components to create
+        @type   components_names:    list
         """
-        # FIXME: not a very clean way to deduce *_providers from *_manager
-        providers_type = self.name[:-8] + "_providers"
         application = common.application
-        providers_names = application.config.get_option(providers_type,
-                                                        section='general',
-                                                        default=[])
-
         plugin_registry = application.plugin_registry
 
-        def load_providers_iter(loaded):
-            def create_component_done(component):
-                self.log("Loaded provider %s" % component.name)
+        def load_components_iter(loaded):
+            def create_component_done(component, component_name):
+                self.debug("Loaded provider %s" % component_name)
                 self.register_component(component)
-                loaded.append(component)
+                return (True, component)
 
-                return component
+            def create_component_failure(failure, component_name):
+                log_path = common.application.log_failure(failure)
+                self.warning("Creating %s failed. A full traceback can"
+                             " be found at %s" % (component_name, log_path))
+                return (False, failure)
 
-            def create_component_failure(failure, provider_name):
-                if failure.type == InitializeFailure:
-                    self.warning("Initializing %s failed: %s." %
-                                 (provider_name, failure.value) )
-                elif failure.type == UnMetDependency:
-                    self.warning("Missing dependency %s to create %s" %
-                                    (failure.value, provider_name))
-                else:
-                    failure_path = application.log_failure(failure)
-                    self.warning("Creating provider %s failed. A full traceback"\
-                             " can be found at %s" %
-                                (provider_name, failure_path) )
-                # continue
-                return
-
-            for provider_name in providers_names:
-                res = defer.maybeDeferred(plugin_registry.create_component,
-                        provider_name)
-                res.addCallback(create_component_done)
-                res.addErrback(create_component_failure, provider_name)
+            for component_name in components_names:
+                res = plugin_registry.create_component(component_name)
+                res.addCallback(create_component_done, component_name)
+                res.addErrback(create_component_failure, component_name)
+                res.addCallback(loaded.append)
 
                 yield res
 
-        def load_providers_iter_done(iter, loaded):
-            self.debug("Loaded %s %s" % (len(loaded), providers_type))
-        
-            return self
+        def load_components_iter_done(iter, loaded):
+            really_loaded = filter(lambda x: x[0], loaded)
+            self.debug("Loaded %s providers" % len(really_loaded))
+            return loaded
 
         loaded = []
-        res_dfr = task.coiterate(load_providers_iter(loaded))
-        res_dfr.addCallback(load_providers_iter_done, loaded)
+        res_dfr = task.coiterate(load_components_iter(loaded))
+        res_dfr.addCallback(load_components_iter_done, loaded)
 
         return res_dfr
 
@@ -142,14 +121,6 @@ class Manager(log.Loggable):
 
         return defer.DeferredList(deferreds)
 
-    def component_registered(self, component):
-        """ Check if a component is registed in the Manager or not
-
-        @param component: the Component to register
-        @type component:  L{elisa.core.component.Component}
-        @rtype:           bool
-        """
-        return component in self._components
 
     def register_component(self, component):
         """ Register a new Component
@@ -161,16 +132,17 @@ class Manager(log.Loggable):
         @param component: the Component to register
         @type component:  L{elisa.core.component.Component}
 
-        @raise AlreadyRegistered : when the component has already been registered
+        @raise AlreadyRegistered : when the component has already
+                                   been registered
+        @raise TypeError:          when the given L{component} is *not* of the
+                                   type L{supported_components}
         """
-
-        if not self.component_registered(component):
-            self.debug("Registering component %s" % component.path)
-            self._components.append(component)
-        else:
-            self.debug("Component %s already registered" % component.path)
+        if component in self._components:
+            self.debug("Component %s already registered" % component)
             raise AlreadyRegistered()
-
+        else:
+            self.debug("Registering component %s" % component)
+            self._components.append(component)
 
     def unregister_component(self, component):
         """ Unregister a component from the Manager
@@ -184,9 +156,9 @@ class Manager(log.Loggable):
         @raise CannotUnregister : raised when the component cannot be removed
         """
 
-        if self.component_registered(component):
-            self.debug("Unregistering component %s" % component.path)
+        if component in self._components:
+            self.debug("Unregistering component %s" % component)
             self._components.remove(component)
         else:
-            self.debug("Impossible to unregister component %s" % component.path)
+            self.debug("Impossible to unregister component %s" % component)
             raise CannotUnregister()
